#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-06-11 12:40:47.360445

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.mec_mod_interfaces.tri_dim_feat_edge import TriDimFeatEdge


class RectilinearTriDimFeatEdge(TriDimFeatEdge):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     InfInterfaces.Reference
                |                         MecModInterfaces.Boundary
                |                             MecModInterfaces.Edge
                |                                MecModInterfaces.TriDimFeatEdge
                |                                     RectilinearTriDimFeatEdge
                | 
                | 1-D boundary belonging to a feature whose topological result is three
                | dimensional, the boundary having a rectilinear geometry.
                | Role: This Boundary object may be, for example, the edge of a Pad resulting
                | from the extrusion of a square.
                | You will create a RectilinearTriDimFeatEdge object using the Shapes.GetBoundary
                | , HybridShapes.GetBoundary , Sketches.GetBoundary or Selection.SelectElement2
                | method. Then, you pass it to the operator (such as Hole.SetDirection
                | ).
                | The lifetime of a RectilinearTriDimFeatEdge object is limited, see
                | Boundary.
                | 
                | Example:
                |     This example asks the end user to select a face, a rectilinear edge, and
                |     creates a hole. The rectilinear edge specifies the hole direction. It may be a
                |     RectilinearTriDimFeatEdge, a RectilinearBiDimFeatEdge or a
                |     RectilinearMonoDimFeatEdge.
                | 
                |      Dim EnabledObjectSelection1(0)
                |      Dim EnabledObjectSelection2(2)
                |      Set Document = CATIA.ActiveDocument
                |      Set Selection = Document.Selection
                |      'We propose to the user that he select a face
                |      EnabledObjectSelection1(0)="Face"
                |      Status=Selection.SelectElement2(EnabledObjectSelection1,"Select a
                |      face",true)
                |      if (Status = "cancel") then Exit Sub
                |      Set Face = Selection.Item(1).Value
                |      Selection.Clear
                |      'We propose to the user that he select the hole direction
                |      EnabledObjectSelection2(0)="RectilinearTriDimFeatEdge"
                |      EnabledObjectSelection2(1)="RectilinearBiDimFeatEdge"
                |      EnabledObjectSelection2(2)="RectilinearMonoDimFeatEdge"
                |      Status=Selection.SelectElement2(EnabledObjectSelection2,"Select the hole
                |      direction",true)
                |      if (Status = "cancel") then Exit Sub
                |      Set Hole = ShapeFactory.AddNewHoleFromPoint(20.0,-5.5, 1.07,Face,10.0)
                |      Hole.ThreadingMode = 1
                |      Hole.ThreadSide = 0
                |      Hole.SetDirection Selection.Item(1).Value
                |      Document.Part.Update
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.rectilinear_tri_dim_feat_edge = com_object

    def get_direction(self, o_direction: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub GetDirection(CATSafeArrayVariant oDirection)
                | 
                |     Returns the direction of the rectilinear edge
                | 
                |     Parameters:
                | 
                |         oDirection[0]
                |             The X Coordinate of the direction 
                |         oDirection[1]
                |             The Y Coordinate of the direction 
                |         oDirection[2]
                |             The Z Coordinate of the direction

        :param tuple o_direction:
        :rtype: None
        """
        return self.rectilinear_tri_dim_feat_edge.GetDirection(o_direction)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_direction'
        # # vba_code = """
        # # Public Function get_direction(rectilinear_tri_dim_feat_edge)
        # #     Dim oDirection (2)
        # #     rectilinear_tri_dim_feat_edge.GetDirection oDirection
        # #     get_direction = oDirection
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def get_origin(self, o_origin: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub GetOrigin(CATSafeArrayVariant oOrigin)
                | 
                |     Returns the origin of the the rectilinear edge.
                | 
                |     Parameters:
                | 
                |         oOrigin[0]
                |             The X Coordinate of the rectilinear edge origin 
                |         oOrigin[1]
                |             The Y Coordinate of the rectilinear edge origin 
                |         oOrigin[2]
                |             The Z Coordinate of the rectilinear edge origin

        :param tuple o_origin:
        :rtype: None
        """
        return self.rectilinear_tri_dim_feat_edge.GetOrigin(o_origin)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_origin'
        # # vba_code = """
        # # Public Function get_origin(rectilinear_tri_dim_feat_edge)
        # #     Dim oOrigin (2)
        # #     rectilinear_tri_dim_feat_edge.GetOrigin oOrigin
        # #     get_origin = oOrigin
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'RectilinearTriDimFeatEdge(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.cat_str_functional_interfaces.sfm_connection_parameters import SFMConnectionParameters
from pycatia.cat_str_functional_interfaces.sfm_references import SFMReferences
from pycatia.system_interfaces.any_object import AnyObject
from pycatia.types.general import cat_variant


class SFMEndcut(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     SfmEndcut
                | 
                | Interface to manage the EndCut on Super Profile.
                | Role: Allows managing (mainly retreiving parameters)on existing
                | EndCut.
                | 
                | See also:
                |     SfmProfile, SfmEndcutManager, SfmConnectionParameters
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.sfm_endcut = com_object

    def get_connection_coordinate(self) -> tuple:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetConnectionCoordinate() As CATSafeArrayVariant
                | 
                |     Gets thelocation of existing endcut.
                | 
                |     Parameters:
                | 
                |         oCoordinate
                |             [out] The Coordinates. 
                | 
                |     Returns:
                |         S_OK if everything ran ok
                | 
                |         Example
                |         :
                |             The example retrieves endcut Coordinates defined on start
                |             end.
                | 
                |              Dim EndcutObj As SfmEndcut
                |              Set EndcutObj = StiffObj.GetEndcut(1)
                |              Dim Coord() As Variant
                |              Dim x,y,z as Double
                |              Coord() = EndcutObj.GetConnectionCoordinate
                |              x = Coord(0)
                |              y = Coord(1)
                |              z = Coord(2)

        :rtype: tuple
        """
        return self.sfm_endcut.GetConnectionCoordinate()

    def get_endcutinfo(
            self,
            o_type_of_endcut: str,
            o_name_of_endcut: str,
            o_list_of_endcut_contexts: SFMReferences,
            o_list_of_endcut_params: SFMConnectionParameters,
            o_list_of_end_cut_param_names: tuple
    ) -> cat_variant:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetEndcutinfo(CATBSTR oTypeOfEndcut,
                | CATBSTR oNameOfEndcut,
                | SfmReferences oListOfEndcutContexts,
                | SfmConnectionParameters oListOfEndcutParams,
                | CATSafeArrayVariant oListOfEndCutParamNames)
                | 
                |     Gets the information on existing Endcut.
                | 
                |     Parameters:
                | 
                |         oTypeOfEndcut
                |             [out] Type of Endcut(Snipe,Trim,Weld). 
                |         oNameOfEndcut
                |             [out] Name of the Endcut. 
                |         oListOfEndcutContexts
                |             [out] List of Contexts (Limits) defined for Cutbacks and Contextual
                |             Endcuts. The list will be empty for custom UDF based endcuts.
                |             
                |         oListOfEndcutParams
                |             [out] List of Parameters set when defining the Endcut.
                |             
                |         oListOfEndCutParamNames
                |             [out] List of Parameter Names set when defining the Endcut.
                |             
                | 
                |     Returns:
                |         S_OK if everything ran ok
                | 
                |         Example
                |         :
                |             The example retrieves endcut information.
                | 
                |              Dim EndcutObj As SfmEndcut
                |              Set EndcutObj = StiffObj.GetEndcut(1)
                |              Dim EndCutName, EndCutType As String
                |              Dim ContextList  As SfmReferences
                |              Dim ParamList As SfmConnectionParameters
                |              Dim ParamNamesList() As Variant
                |              EndcutObj.GetEndcutinfo EndCutType, EndCutName, ContextList,
                |              ParamList, ParamNamesList

        :param str o_type_of_endcut:
        :param str o_name_of_endcut:
        :param SFMReferences o_list_of_endcut_contexts:
        :param SFMConnectionParameters o_list_of_endcut_params:
        :param tuple o_list_of_end_cut_param_names:
        :rtype: cat_variant
        """
        return self.sfm_endcut.GetEndcutinfo(
            o_type_of_endcut,
            o_name_of_endcut,
            o_list_of_endcut_contexts.com_object,
            o_list_of_endcut_params.com_object,
            o_list_of_end_cut_param_names
        )
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_endcutinfo'
        # # vba_code = """
        # # Public Function get_endcutinfo(sfm_endcut)
        # #     Dim oTypeOfEndcut (2)
        # #     sfm_endcut.GetEndcutinfo oTypeOfEndcut
        # #     get_endcutinfo = oTypeOfEndcut
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def update_connections_set(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub UpdateConnectionsSet()
                | 
                |     Updates the Connection Set.
                | 
                |     Returns:
                |         S_OK if everything ran ok
                | 
                |         Example
                |         :
                |             The example Updates the Connection Set.
                | 
                |              Dim EndcutObj As SfmEndcut
                |              Set EndcutObj = StiffObj.GetEndcut(1)
                |              EndcutObj.UpdateConnectionsSet

        :rtype: None
        """
        return self.sfm_endcut.UpdateConnectionsSet()

    def __repr__(self):
        return f'SFMEndcut(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.cat_sch_platform_interfaces.sch_list_of_objects import SchListOfObjects
from pycatia.system_interfaces.any_object import AnyObject


class SchAppCompatible(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     SchAppCompatible
                | 
                | Provide application rules of how to connect objects.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.sch_app_compatible = com_object

    def app_is_target_ok_for_insert(
            self,
            i_l_comp_source_cntrs: SchListOfObjects,
            o_l_source_cntrs: SchListOfObjects,
            o_b_yes: bool
    ) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub AppIsTargetOKForInsert(SchListOfObjects
                | iLCompSourceCntrs,
                | SchListOfObjects oLSourceCntrs,
                | boolean oBYes)
                | 
                |     Query whether a component (source) is compatible to be inserted into this
                |     route. This method is used when inserting a component into a route. This mehtod
                |     should only be implemented on a route object. For a component object, the
                |     method should simply returns oBYes=FALSE.
                | 
                |     Parameters:
                | 
                |         iLCompSourceCntrs
                |             A list of connectors on the source component. The target (to be
                |             connected) is "this" route. 
                |         oLSourceCntrs
                |             A list of compatible and available connectors on the source
                |             component (the input) that can be connected to the target ("this" route)
                |             (members are CATISchAppConnector interface pointers)
                |             
                |         oBYes
                |             If TRUE, the object is OK to be connected to a route.
                |
                |     Example:
                |
                |          Dim objThisIntf As SchAppCompatible
                |          Dim objArg1 As SchListOfObjects
                |          Dim objArg2 As SchListOfObjects
                |          Dim bVar3 As boolean
                |           ...
                |         objThisIntf.AppIsTargetOKForInsertobjArg1,objArg2,bVar3

        :param SchListOfObjects i_l_comp_source_cntrs:
        :param SchListOfObjects o_l_source_cntrs:
        :param bool o_b_yes:
        :rtype: None
        """
        return self.sch_app_compatible.AppIsTargetOKForInsert(
            i_l_comp_source_cntrs.com_object,
            o_l_source_cntrs.com_object,
            o_b_yes
        )
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'app_is_target_ok_for_insert'
        # # vba_code = """
        # # Public Function app_is_target_ok_for_insert(sch_app_compatible)
        # #     Dim iLCompSourceCntrs (2)
        # #     sch_app_compatible.AppIsTargetOKForInsert iLCompSourceCntrs
        # #     app_is_target_ok_for_insert = iLCompSourceCntrs
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def app_is_target_ok_for_place(
            self,
            i_l_comp_source_cntrs: SchListOfObjects,
            o_l_target_cntrs: SchListOfObjects,
            o_b_yes: bool
    ) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub AppIsTargetOKForPlace(SchListOfObjects
                | iLCompSourceCntrs,
                | SchListOfObjects oLTargetCntrs,
                | boolean oBYes)
                | 
                |     Query whether a component (source) is compatible to be connected to "this"
                |     object (the target, which can be a route or a component). This method is used
                |     when placing a component to be connected to another
                |     object.
                | 
                |     Parameters:
                | 
                |         iLCompSourceCntrs
                |             A list of connectors on the source component. The target (to be
                |             connected) is "this" component. 
                |         oLOKCntrs
                |             A list of compatible and available connectors on "this" component
                |             (the target) to be connected to the source component (the input source).
                |             (members are CATISchAppConnector interface pointers)
                |             
                |         oBYes
                |             If TRUE, the object is OK to be connected to a route.
                |
                |     Example:
                |
                |          Dim objThisIntf As SchAppCompatible
                |          Dim objArg1 As SchListOfObjects
                |          Dim objArg2 As SchListOfObjects
                |          Dim bVar3 As boolean
                |           ...
                |         
                |         objThisIntf.AppIsTargetOKForPlaceobjArg1,objArg2,bVar3

        :param SchListOfObjects i_l_comp_source_cntrs:
        :param SchListOfObjects o_l_target_cntrs:
        :param bool o_b_yes:
        :rtype: None
        """
        return self.sch_app_compatible.AppIsTargetOKForPlace(
            i_l_comp_source_cntrs.com_object,
            o_l_target_cntrs.com_object,
            o_b_yes
        )
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'app_is_target_ok_for_place'
        # # vba_code = """
        # # Public Function app_is_target_ok_for_place(sch_app_compatible)
        # #     Dim iLCompSourceCntrs (2)
        # #     sch_app_compatible.AppIsTargetOKForPlace iLCompSourceCntrs
        # #     app_is_target_ok_for_place = iLCompSourceCntrs
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def app_is_target_ok_for_route(
            self,
            i_route_cntr_class_type: str,
            o_lok_cntrs: SchListOfObjects,
            o_b_yes: bool
    ) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub AppIsTargetOKForRoute(CATBSTR iRouteCntrClassType,
                | SchListOfObjects oLOKCntrs,
                | boolean oBYes)
                | 
                |     Query whether a route of the input class type can be connected to "this"
                |     object (the target, which can be a route or a component). This method is used
                |     when routing a route.
                | 
                |     Parameters:
                | 
                |         iRouteCntrClassType
                |             Class type of a schematic route connector. 
                |         oLOKCntrs
                |             A list of compatible and available connectors on this object.
                |             (members are CATISchAppConnector interface pointers)
                |             
                |         oBYes
                |             If TRUE, the object is OK to be connected to a route.
                |             
                | 
                |     Example:
                |
                |          Dim objThisIntf As SchAppCompatible
                |          Dim strVar1 As String
                |          Dim objArg2 As SchListOfObjects
                |          Dim bVar3 As boolean
                |           ...
                |         
                |         objThisIntf.AppIsTargetOKForRoutestrVar1,objArg2,bVar3

        :param str i_route_cntr_class_type:
        :param SchListOfObjects o_lok_cntrs:
        :param bool o_b_yes:
        :rtype: None
        """
        return self.sch_app_compatible.AppIsTargetOKForRoute(
            i_route_cntr_class_type,
            o_lok_cntrs.com_object,
            o_b_yes
        )
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'app_is_target_ok_for_route'
        # # vba_code = """
        # # Public Function app_is_target_ok_for_route(sch_app_compatible)
        # #     Dim iRouteCntrClassType (2)
        # #     sch_app_compatible.AppIsTargetOKForRoute iRouteCntrClassType
        # #     app_is_target_ok_for_route = iRouteCntrClassType
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'SchAppCompatible(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-07-06 14:02:20.222384

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.mec_mod_interfaces.hybrid_shape import HybridShape


class Plane(HybridShape):

    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     MecModInterfaces.HybridShape
                |                         Plane
                | 
                | Represents the hybrid shape Plane feature object.
                | Role: Declare hybrid shape Plane root feature object. All interfaces for
                | different type of Plane derives HybridShapePlane.
                | 
                | Use the CATIAHybridShapeFactory to create a HybridShapePlane
                | objects.
                | 
                | See also:
                |     HybridShapeFactory
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.plane = com_object

    def get_first_axis(self, o_first_axis: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub GetFirstAxis(CATSafeArrayVariant oFirstAxis)
                | 
                |     Returns the coordinates of the first plane axis.
                | 
                |     Parameters:
                | 
                |         oFirstAxis[0]
                |             The X Coordinate of the first plane axis 
                |         oFirstAxis[1]
                |             The Y Coordinate of the first plane axis 
                |         oFirstAxis[2]
                |             The Z Coordinate of the first plane axis 
                | 
                |     See also:
                |         HybridShapeFactory

        :param tuple o_first_axis:
        :rtype: None
        """
        return self.plane.GetFirstAxis(o_first_axis)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_first_axis'
        # # vba_code = """
        # # Public Function get_first_axis(plane)
        # #     Dim oFirstAxis (2)
        # #     plane.GetFirstAxis oFirstAxis
        # #     get_first_axis = oFirstAxis
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def get_origin(self, o_origin: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub GetOrigin(CATSafeArrayVariant oOrigin)
                | 
                |     Returns the origin of the plane.
                | 
                |     Parameters:
                | 
                |         oOrigin[0]
                |             The X Coordinate of the plane origin 
                |         oOrigin[1]
                |             The Y Coordinate of the plane origin 
                |         oOrigin[2]
                |             The Z Coordinate of the plane origin 
                | 
                |     See also:
                |         HybridShapeFactory

        :param tuple o_origin:
        :rtype: None
        """
        return self.plane.GetOrigin(o_origin)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_origin'
        # # vba_code = """
        # # Public Function get_origin(plane)
        # #     Dim oOrigin (2)
        # #     plane.GetOrigin oOrigin
        # #     get_origin = oOrigin
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def get_position(self, o_x: float, o_y: float, o_z: float) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub GetPosition(double oX,
                | double oY,
                | double oZ)
                | 
                |     Gets the position where the plane is displayed.
                | 
                |     Parameters:
                | 
                |         oX
                |             X coordinates 
                |         oY
                |             Y coordinates 
                |         oZ
                |             Z coordinates 
                | 
                |     Returns:
                |         S_OK if the position has been set before, E_FAIL else.

        :param float o_x:
        :param float o_y:
        :param float o_z:
        :rtype: None
        """
        return self.plane.GetPosition(o_x, o_y, o_z)

    def get_second_axis(self, o_second_axis: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub GetSecondAxis(CATSafeArrayVariant oSecondAxis)
                | 
                |     Returns the coordinates of the second plane axis.
                | 
                |     Parameters:
                | 
                |         oSecondAxis[0]
                |             The X Coordinate of the second plane axis 
                |         oSecondAxis[1]
                |             The Y Coordinate of the second plane axis 
                |         oSecondAxis[2]
                |             The Z Coordinate of the second plane axis 
                | 
                |     See also:
                |         HybridShapeFactory

        :param tuple o_second_axis:
        :rtype: None
        """
        return self.plane.GetSecondAxis(o_second_axis)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_second_axis'
        # # vba_code = """
        # # Public Function get_second_axis(plane)
        # #     Dim oSecondAxis (2)
        # #     plane.GetSecondAxis oSecondAxis
        # #     get_second_axis = oSecondAxis
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def is_a_ref_plane(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func IsARefPlane() As long
                | 
                |     Queries whether the plane is a reference plane (fixed axis
                |     plane).
                | 
                |     Returns:
                |         0 when the plane is a reference plane, 1 else.

        :rtype: int
        """
        return self.plane.IsARefPlane()

    def put_first_axis(self, i_first_axis: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub PutFirstAxis(CATSafeArrayVariant iFirstAxis)
                | 
                |     Sets the first axis. The first plane axis must be a point-direction
                |     line.
                |     Note: This method can only be used on CATIAHybridShapePlane2Lines
                |     feature
                | 
                |     Parameters:
                | 
                |         iFirstAxis[0]
                |             The X Coordinate of the first plane axis 
                |         iFirstAxis[1]
                |             The Y Coordinate of the first plane axis 
                |         iFirstAxis[2]
                |             The Z Coordinate of the first plane axis 
                | 
                |     See also:
                |         HybridShapeFactory

        :param tuple i_first_axis:
        :rtype: None
        """
        return self.plane.PutFirstAxis(i_first_axis)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'put_first_axis'
        # # vba_code = """
        # # Public Function put_first_axis(plane)
        # #     Dim iFirstAxis (2)
        # #     plane.PutFirstAxis iFirstAxis
        # #     put_first_axis = iFirstAxis
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def put_origin(self, i_origin: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub PutOrigin(CATSafeArrayVariant iOrigin)
                | 
                |     Sets the origin of the plane.
                |     Note: This method can only be used on CATIAHybridShapePlane2Lines
                |     feature
                | 
                |     Parameters:
                | 
                |         iOrigin[0]
                |             The X Coordinate of the plane origin 
                |         iOrigin[1]
                |             The Y Coordinate of the plane origin 
                |         iOrigin[2]
                |             The Z Coordinate of the plane origin 
                | 
                |     See also:
                |         HybridShapeFactory

        :param tuple i_origin:
        :rtype: None
        """
        return self.plane.PutOrigin(i_origin)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'put_origin'
        # # vba_code = """
        # # Public Function put_origin(plane)
        # #     Dim iOrigin (2)
        # #     plane.PutOrigin iOrigin
        # #     put_origin = iOrigin
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def put_second_axis(self, i_second_axis: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub PutSecondAxis(CATSafeArrayVariant iSecondAxis)
                | 
                |     Sets the coordinates of the second plane axis. The second plane axis must
                |     be a point-direction line
                |     Note: This method can only be used on CATIAHybridShapePlane2Lines
                |     feature
                | 
                |     Parameters:
                | 
                |         iSecondAxis[0]
                |             The X Coordinate of the second plane axis 
                |         iSecondAxis[1]
                |             The Y Coordinate of the second plane axis 
                |         iSecondAxis[2]
                |             The Z Coordinate of the second plane axis 
                | 
                |     See also:
                |         HybridShapeFactory

        :param tuple i_second_axis:
        :rtype: None
        """
        return self.plane.PutSecondAxis(i_second_axis)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'put_second_axis'
        # # vba_code = """
        # # Public Function put_second_axis(plane)
        # #     Dim iSecondAxis (2)
        # #     plane.PutSecondAxis iSecondAxis
        # #     put_second_axis = iSecondAxis
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def remove_position(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub RemovePosition()
                | 
                |     Removes reference position of a plane.
                |     Note: When removed, the plane is displayed at its default position.

        :rtype: None
        """
        return self.plane.RemovePosition()

    def set_position(self, i_x: float, i_y: float, i_z: float) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetPosition(double iX,
                | double iY,
                | double iZ)
                | 
                |     Sets the position where the plane is displayed.
                | 
                |     Parameters:
                | 
                |         iX
                |             X coordinates 
                |         iY
                |             Y coordinates 
                |         iZ
                |             Z coordinates

        :param float i_x:
        :param float i_y:
        :param float i_z:
        :rtype: None
        """
        return self.plane.SetPosition(i_x, i_y, i_z)

    def __repr__(self):
        return f'Plane(name="{ self.name }")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.analysis_interfaces.analysis_mesh_parts import AnalysisMeshParts
from pycatia.analysis_interfaces.analysis_set import AnalysisSet


class AnalysisMeshManager(AnalysisSet):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     CATAnalysisInterfaces.AnalysisSet
                |                         AnalysisMeshManager
                | 
                | The interface to access a CATIAAnalysisMeshManager.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.analysis_mesh_manager = com_object

    @property
    def analysis_mesh_parts(self) -> AnalysisMeshParts:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property AnalysisMeshParts() As AnalysisMeshParts (Read
                | Only)
                | 
                |     Returns the meshpart collection from the current analysis mesh manager.

        :rtype: AnalysisMeshParts
        """

        return AnalysisMeshParts(self.analysis_mesh_manager.AnalysisMeshParts)

    def __repr__(self):
        return f'AnalysisMeshManager(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.system_interfaces.any_object import AnyObject


class WIText(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     WIText

    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.wi_text = com_object

    @property
    def fixed_text(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property FixedText() As CATBSTR
                | 
                |     Returns or sets the value for 'Fixed Text'
                |     Role: Returns or sets the value of 'Fixed Text' to the Activity

        :rtype: str
        """

        return self.wi_text.FixedText

    @fixed_text.setter
    def fixed_text(self, value: str):
        """
        :param str value:
        """

        self.wi_text.FixedText = value

    @property
    def resolved_text(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property ResolvedText() As CATBSTR
                | 
                |     Returns or sets the value for 'ResolvedText Text'
                |     Role: Returns or sets the value of 'ResolvedText Text' to the Activity

        :rtype: str
        """

        return self.wi_text.ResolvedText

    @resolved_text.setter
    def resolved_text(self, value: str):
        """
        :param str value:
        """

        self.wi_text.ResolvedText = value

    @property
    def unresolved_text(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property UnresolvedText() As CATBSTR
                | 
                |     Returns or sets the value for 'UnresolvedText Text'
                |     Role: Returns or sets the value of 'UnresolvedText Text' to the Activity

        :rtype: str
        """

        return self.wi_text.UnresolvedText

    @unresolved_text.setter
    def unresolved_text(self, value: str):
        """
        :param str value:
        """

        self.wi_text.UnresolvedText = value

    def get_attribute(self, i_attr_name: str) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetAttribute(CATBSTR iAttrName) As CATBSTR
                | 
                |     This gets the value of the Attribute.
                | 
                |     Parameters:
                | 
                |         iAttrName
                |             The Attribute Name whose value we need to get 
                |         iAttrValue
                |             CATUnicodeString value of the Attribute

        :param str i_attr_name:
        :rtype: str
        """
        return self.wi_text.GetAttribute(i_attr_name)

    def get_geom_associated_to_annotation(self, i_assignment_type: int, io_point_geom: AnyObject) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetGeomAssociatedToAnnotation(ItemAssignmentType
                | iAssignmentType,
                | CATBaseDispatch ioPointGeom)
                | 
                |     Gets the underlying geometry associated to FTA Text Annotation which is
                |     added as an item to operation of one WIText Activity or added as item to a
                |     WIText activity. This should be used in case when FTA Text Annotation is
                |     associated to single geometric entity.
                | 
                |     Parameters:
                | 
                |         iAssignmentType
                |             Point geometry associated to FTA text. 
                |         iAssignmentType
                |             Type of the Assignment (Item to the Process) 
                | 
                |     Returns:
                |         Legal values:
                |         S_OK : on Success
                |         E_FAIL: on failure

        :param int i_assignment_type: enum item_assignment_type
        :param AnyObject io_point_geom:
        :rtype: None
        """
        return self.wi_text.GetGeomAssociatedToAnnotation(i_assignment_type, io_point_geom.com_object)

    def get_hyper_links(self) -> tuple:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetHyperLinks() As CATSafeArrayVariant
                | 
                |     Retrieves the List of Hyperlinks associated to this
                |     activity
                |     Role: Retrieves the List of Hyperlinks associated to this
                |     activity
                | 
                |     Parameters:
                | 
                |         ioPath
                |             a CATSafeArrayVariant of CATBSTR that has the list of Hyperlinks
                |
                |     Returns:
                |         Legal values:
                |         S_OK : on Success
                |         E_FAIL: on failure

        :rtype: tuple
        """
        return self.wi_text.GetHyperLinks()

    def set_attribute(self, i_attr_name: str, i_attr_value: str) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetAttribute(CATBSTR iAttrName,
                | CATBSTR iAttrValue)
                | 
                |     This sets the value of the Attribute
                | 
                |     Parameters:
                | 
                |         iAttrName
                |             The Attribute Name whose value we need to get 
                |         iAttrValue
                |             CATUnicodeString value of the Attribute

        :param str i_attr_name:
        :param str i_attr_value:
        :rtype: None
        """
        return self.wi_text.SetAttribute(i_attr_name, i_attr_value)

    def set_hyper_links(self, i_hyperlinks: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetHyperLinks(CATSafeArrayVariant iHyperlinks)
                | 
                |     Sets a List of Hyperlinks to this activity
                |     Role: Sets the List of Hyperlinks to this activity
                | 
                |     Parameters:
                | 
                |         iPath
                |             a CATSafeArrayVariant of CATBSTR that has the list of Hyperlinks.
                |
                |     Returns:
                |         Legal values:
                |         S_OK : on Success
                |         E_FAIL: on failure

        :param tuple i_hyperlinks:
        :rtype: None
        """
        return self.wi_text.SetHyperLinks(i_hyperlinks)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_hyper_links'
        # # vba_code = """
        # # Public Function set_hyper_links(wi_text)
        # #     Dim iHyperlinks (2)
        # #     wi_text.SetHyperLinks iHyperlinks
        # #     set_hyper_links = iHyperlinks
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'WIText(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.system_interfaces.setting_controller import SettingController


class AnalysisReportingSettingAtt(SettingController):

    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     System.SettingController
                |                         AnalysisReportingSettingAtt
                | 
                | Interface to handle the Analysis & Simulation
                | "ReportingSetting".
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.analysis_reporting_setting_att = com_object

    @property
    def background_image_mode(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property BackgroundImageMode() As boolean
                | 
                |     Returns or sets the BackgroundImageMode parameter.
                | 
                |     Ensure consistency with the C++ interface to which the work is delegated.

        :rtype: bool
        """

        return self.analysis_reporting_setting_att.BackgroundImageMode

    @background_image_mode.setter
    def background_image_mode(self, value: bool):
        """
        :param bool value:
        """

        self.analysis_reporting_setting_att.BackgroundImageMode = value

    @property
    def custom_background_image(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property CustomBackgroundImage() As CATBSTR
                | 
                |     Returns or sets the CustomBackgroundImage parameter.
                | 
                |     Ensure consistency with the C++ interface to which the work is delegated.

        :rtype: str
        """

        return self.analysis_reporting_setting_att.CustomBackgroundImage

    @custom_background_image.setter
    def custom_background_image(self, value: str):
        """
        :param str value:
        """

        self.analysis_reporting_setting_att.CustomBackgroundImage = value

    @property
    def custom_image_format(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property CustomImageFormat() As CATBSTR
                | 
                |     Returns or sets the CustomImageFormat parameter.
                | 
                |     Ensure consistency with the C++ interface to which the work is delegated.

        :rtype: str
        """

        return self.analysis_reporting_setting_att.CustomImageFormat

    @custom_image_format.setter
    def custom_image_format(self, value: str):
        """
        :param str value:
        """

        self.analysis_reporting_setting_att.CustomImageFormat = value

    @property
    def custom_image_height(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property CustomImageHeight() As long
                | 
                |     Returns or sets the CustomImageHeight parameter.
                | 
                |     Ensure consistency with the C++ interface to which the work is delegated.

        :rtype: int
        """

        return self.analysis_reporting_setting_att.CustomImageHeight

    @custom_image_height.setter
    def custom_image_height(self, value: int):
        """
        :param int value:
        """

        self.analysis_reporting_setting_att.CustomImageHeight = value

    @property
    def custom_image_width(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property CustomImageWidth() As long
                | 
                |     Returns or sets the CustomImageWidth parameter.
                | 
                |     Ensure consistency with the C++ interface to which the work is delegated.

        :rtype: int
        """

        return self.analysis_reporting_setting_att.CustomImageWidth

    @custom_image_width.setter
    def custom_image_width(self, value: int):
        """
        :param int value:
        """

        self.analysis_reporting_setting_att.CustomImageWidth = value

    @property
    def image_quality_mode(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property ImageQualityMode() As boolean
                | 
                |     Returns or sets the ImageQualityMode parameter.
                | 
                |     Ensure consistency with the C++ interface to which the work is delegated.

        :rtype: bool
        """

        return self.analysis_reporting_setting_att.ImageQualityMode

    @image_quality_mode.setter
    def image_quality_mode(self, value: bool):
        """
        :param bool value:
        """

        self.analysis_reporting_setting_att.ImageQualityMode = value

    @property
    def temp_output_directory(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property TempOutputDirectory() As CATBSTR
                | 
                |     Returns or sets the TempOutputDirectory parameter.
                | 
                |     Ensure consistency with the C++ interface to which the work is delegated.

        :rtype: str
        """

        return self.analysis_reporting_setting_att.TempOutputDirectory

    @temp_output_directory.setter
    def temp_output_directory(self, value: str):
        """
        :param str value:
        """

        self.analysis_reporting_setting_att.TempOutputDirectory = value

    def get_background_image_mode_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetBackgroundImageModeInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the BackgroundImageMode
                |     parameter.
                |     Role:Retrieves the state of the BackgroundImageMode parameter in the
                |     current environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.analysis_reporting_setting_att.GetBackgroundImageModeInfo(io_admin_level, io_locked)

    def get_custom_background_image_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetCustomBackgroundImageInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the CustomBackgroundImage
                |     parameter.
                |     Role:Retrieves the state of the CustomBackgroundImage parameter in the
                |     current environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.analysis_reporting_setting_att.GetCustomBackgroundImageInfo(io_admin_level, io_locked)

    def get_custom_image_format_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetCustomImageFormatInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the CustomImageFormat
                |     parameter.
                |     Role:Retrieves the state of the CustomImageFormat parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.analysis_reporting_setting_att.GetCustomImageFormatInfo(io_admin_level, io_locked)

    def get_custom_image_height_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetCustomImageHeightInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the CustomImageHeight
                |     parameter.
                |     Role:Retrieves the state of the CustomImageHeight parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.analysis_reporting_setting_att.GetCustomImageHeightInfo(io_admin_level, io_locked)

    def get_custom_image_width_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetCustomImageWidthInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the CustomImageWidth
                |     parameter.
                |     Role:Retrieves the state of the CustomImageWidth parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.analysis_reporting_setting_att.GetCustomImageWidthInfo(io_admin_level, io_locked)

    def get_image_quality_mode_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetImageQualityModeInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the ImageQualityMode
                |     parameter.
                |     Role:Retrieves the state of the ImageQualityMode parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.analysis_reporting_setting_att.GetImageQualityModeInfo(io_admin_level, io_locked)

    def get_temp_output_directory_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetTempOutputDirectoryInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the TempOutputDirectory
                |     parameter.
                |     Role:Retrieves the state of the TempOutputDirectory parameter in the
                |     current environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.analysis_reporting_setting_att.GetTempOutputDirectoryInfo(io_admin_level, io_locked)

    def set_background_image_mode_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetBackgroundImageModeLock(boolean iLocked)
                | 
                |     Locks or unlocks the BackgroundImageMode parameter.
                |     Role:Locks or unlocks the BackgroundImageMode parameter if it is possible
                |     in the current administrative context. In user mode this method will always
                |     return E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.analysis_reporting_setting_att.SetBackgroundImageModeLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_background_image_mode_lock'
        # # vba_code = """
        # # Public Function set_background_image_mode_lock(analysis_reporting_setting_att)
        # #     Dim iLocked (2)
        # #     analysis_reporting_setting_att.SetBackgroundImageModeLock iLocked
        # #     set_background_image_mode_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_custom_background_image_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetCustomBackgroundImageLock(boolean iLocked)
                | 
                |     Locks or unlocks the CustomBackgroundImage parameter.
                |     Role:Locks or unlocks the CustomBackgroundImage parameter if it is possible
                |     in the current administrative context. In user mode this method will always
                |     return E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.analysis_reporting_setting_att.SetCustomBackgroundImageLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_custom_background_image_lock'
        # # vba_code = """
        # # Public Function set_custom_background_image_lock(analysis_reporting_setting_att)
        # #     Dim iLocked (2)
        # #     analysis_reporting_setting_att.SetCustomBackgroundImageLock iLocked
        # #     set_custom_background_image_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_custom_image_format_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetCustomImageFormatLock(boolean iLocked)
                | 
                |     Locks or unlocks the CustomImageFormat parameter.
                |     Role:Locks or unlocks the CustomImageFormat parameter if it is possible in
                |     the current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.analysis_reporting_setting_att.SetCustomImageFormatLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_custom_image_format_lock'
        # # vba_code = """
        # # Public Function set_custom_image_format_lock(analysis_reporting_setting_att)
        # #     Dim iLocked (2)
        # #     analysis_reporting_setting_att.SetCustomImageFormatLock iLocked
        # #     set_custom_image_format_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_custom_image_height_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetCustomImageHeightLock(boolean iLocked)
                | 
                |     Locks or unlocks the CustomImageHeight parameter.
                |     Role:Locks or unlocks the ImageHeight parameter if it is possible in the
                |     current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.analysis_reporting_setting_att.SetCustomImageHeightLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_custom_image_height_lock'
        # # vba_code = """
        # # Public Function set_custom_image_height_lock(analysis_reporting_setting_att)
        # #     Dim iLocked (2)
        # #     analysis_reporting_setting_att.SetCustomImageHeightLock iLocked
        # #     set_custom_image_height_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_custom_image_width_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetCustomImageWidthLock(boolean iLocked)
                | 
                |     Locks or unlocks the ImageWidth parameter.
                |     Role:Locks or unlocks the ImageWidth parameter if it is possible in the
                |     current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.analysis_reporting_setting_att.SetCustomImageWidthLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_custom_image_width_lock'
        # # vba_code = """
        # # Public Function set_custom_image_width_lock(analysis_reporting_setting_att)
        # #     Dim iLocked (2)
        # #     analysis_reporting_setting_att.SetCustomImageWidthLock iLocked
        # #     set_custom_image_width_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_image_quality_mode_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetImageQualityModeLock(boolean iLocked)
                | 
                |     Locks or unlocks the ImageQualityMode parameter.
                |     Role:Locks or unlocks the DefaultImageQuality parameter if it is possible
                |     in the current administrative context. In user mode this method will always
                |     return E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.analysis_reporting_setting_att.SetImageQualityModeLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_image_quality_mode_lock'
        # # vba_code = """
        # # Public Function set_image_quality_mode_lock(analysis_reporting_setting_att)
        # #     Dim iLocked (2)
        # #     analysis_reporting_setting_att.SetImageQualityModeLock iLocked
        # #     set_image_quality_mode_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_temp_output_directory_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetTempOutputDirectoryLock(boolean iLocked)
                | 
                |     Locks or unlocks the TempOutputDirectory parameter.
                |     Role:Locks or unlocks the TempOutputDirectory parameter if it is possible
                |     in the current administrative context. In user mode this method will always
                |     return E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.analysis_reporting_setting_att.SetTempOutputDirectoryLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_temp_output_directory_lock'
        # # vba_code = """
        # # Public Function set_temp_output_directory_lock(analysis_reporting_setting_att)
        # #     Dim iLocked (2)
        # #     analysis_reporting_setting_att.SetTempOutputDirectoryLock iLocked
        # #     set_temp_output_directory_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'AnalysisReportingSettingAtt(name="{ self.name }")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.cat_plant_ship_interfaces.psp_list_of_doubles import PSPListOfDoubles
from pycatia.product_structure_interfaces.product import Product
from pycatia.system_interfaces.any_object import AnyObject


class PSPLightConnector(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     PspLightConnector
                | 
                | Represents the light connector.
                | Role: To access light connector data.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.psp_light_connector = com_object

    def get_alignment_vector(self, i_rel_axis: Product) -> PSPListOfDoubles:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetAlignmentVector(Product iRelAxis) As
                | PspListOfDoubles
                | 
                |     Returns the position of the connector.
                | 
                |     Parameters:
                | 
                |         iRelAxis
                |             the relative axis object (Nothing means relative to parent)
                |             
                |         oAlignmentDirection
                |             Three double values stand for X,Y,Z components of the alignment
                |             vector 
                | 
                |     Example:
                |
                |          Dim objThisIntf As PspLightConnector
                |          Dim objArg1 As Product
                |          Dim objArg2 As PspListOfDoubles
                |           ...
                |          Set objArg2 = objThisIntf.GetAlignmentVector (objArg1)

        :param Product i_rel_axis:
        :rtype: PSPListOfDoubles
        """
        return PSPListOfDoubles(self.psp_light_connector.GetAlignmentVector(i_rel_axis.com_object))

    def get_orientation_vector(self, i_rel_axis: Product) -> PSPListOfDoubles:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetOrientationVector(Product iRelAxis) As
                | PspListOfDoubles
                | 
                |     Returns the Orientation Direction of the connector.
                | 
                |     Parameters:
                | 
                |         iRelAxis
                |             the relative axis object (Nothing means relative to parent)
                |             
                |         oAlignmentDirection
                |             Three double values stand for X,Y,Z components of the alignment
                |             vector 
                | 
                |     Example:
                |
                |          Dim objThisIntf As PspLightConnector
                |          Dim objArg1 As Product
                |          Dim objArg2 As PspListOfDoubles
                |           ...
                |          Set objArg2 = objThisIntf.GetOrientationVector (objArg1)

        :param Product i_rel_axis:
        :rtype: PSPListOfDoubles
        """
        return PSPListOfDoubles(self.psp_light_connector.GetOrientationVector(i_rel_axis.com_object))

    def get_origin(self, i_rel_axis: Product) -> PSPListOfDoubles:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetOrigin(Product iRelAxis) As PspListOfDoubles
                | 
                |     Returns the position of the connector.
                | 
                |     Parameters:
                | 
                |         iRelAxis
                |             the relative axis object (Nothing means relative to parent)
                |             
                |         oOrigin
                |             Origin point position-three double values stand for x,y,z
                |
                |     Example:
                |
                |          Dim objThisIntf As PspLightConnector
                |          Dim objArg1 As Product
                |          Dim objArg2 As PspListOfDoubles
                |           ...
                |          Set objArg2 = objThisIntf.GetOrigin (objArg1)

        :param Product i_rel_axis:
        :rtype: PSPListOfDoubles
        """
        return PSPListOfDoubles(self.psp_light_connector.GetOrigin(i_rel_axis.com_object))

    def set_alignment_vector(self, i_rel_axis: Product, i_alignment_direction: tuple) -> tuple:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetAlignmentVector(Product iRelAxis,
                | CATSafeArrayVariant iAlignmentDirection)
                | 
                |     Sets the alignment direction of the connector.
                | 
                |     Parameters:
                | 
                |         iRelAxis
                |             the relative axis object (Nothing means relative to parent)
                |             
                |         iAlignmentDirection
                |             Three double values stand for X,Y,Z component of the Alignment
                |             vector 
                | 
                |     Example:
                |
                |          Dim objThisIntf As PspLightConnector
                |          Dim objArg1 As  Product
                |          Dim dbVar2(2) As CATSafeArrayVariant
                |           ...
                |          objThisIntf.SetAlignmentVector objArg1, dbVar2

        :param Product i_rel_axis:
        :param tuple i_alignment_direction:
        :rtype: tuple
        """
        return self.psp_light_connector.SetAlignmentVector(i_rel_axis.com_object, i_alignment_direction)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_alignment_vector'
        # # vba_code = """
        # # Public Function set_alignment_vector(psp_light_connector)
        # #     Dim iRelAxis (2)
        # #     psp_light_connector.SetAlignmentVector iRelAxis
        # #     set_alignment_vector = iRelAxis
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_orientation_vector(self, i_rel_axis: Product, i_orientation_direction: tuple) -> tuple:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetOrientationVector(Product iRelAxis,
                | CATSafeArrayVariant iOrientationDirection)
                | 
                |     Sets the Orientation Direction of the connector.
                | 
                |     Parameters:
                | 
                |         iRelAxis
                |             the relative axis object (Nothing means relative to parent)
                |             
                |         iAlignmentDirection
                |             Three double values stand for X,Y,Z component of the Alignment
                |             vector 
                | 
                |     Example:
                |
                |          Dim objThisIntf As PspLightConnector
                |          Dim objArg1 As  Product
                |          Dim dbVar2(2) As CATSafeArrayVariant
                |           ...
                |          objThisIntf.SetAlignmentVector objArg1, dbVar2

        :param Product i_rel_axis:
        :param tuple i_orientation_direction:
        :rtype: tuple
        """
        return self.psp_light_connector.SetOrientationVector(i_rel_axis.com_object, i_orientation_direction)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_orientation_vector'
        # # vba_code = """
        # # Public Function set_orientation_vector(psp_light_connector)
        # #     Dim iRelAxis (2)
        # #     psp_light_connector.SetOrientationVector iRelAxis
        # #     set_orientation_vector = iRelAxis
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_origin(self, i_rel_axis: Product, i_db3_position: tuple) -> tuple:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetOrigin(Product iRelAxis,
                | CATSafeArrayVariant iDb3Position)
                | 
                |     Sets the position of the connector.
                | 
                |     Parameters:
                | 
                |         iRelAxis
                |             the relative axis object (Nothing means relative to parent)
                |             
                |         iDb3Position
                |             absolute X-Y-Z coordinates of the current position of the connector
                |             to be set 
                | 
                |     Example:
                |
                |          Dim objThisIntf As PspLightConnector
                |          Dim objArg1 As  Product
                |          Dim dbVar2(3) As CATSafeArrayVariant
                |           ...
                |          objThisIntf.SetOrigin objArg1, dbVar2

        :param Product i_rel_axis:
        :param tuple i_db3_position:
        :rtype: tuple
        """
        return self.psp_light_connector.SetOrigin(i_rel_axis.com_object, i_db3_position)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_origin'
        # # vba_code = """
        # # Public Function set_origin(psp_light_connector)
        # #     Dim iRelAxis (2)
        # #     psp_light_connector.SetOrigin iRelAxis
        # #     set_origin = iRelAxis
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'PSPLightConnector(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.in_interfaces.document import Document
from pycatia.system_interfaces.collection import Collection
from pycatia.types.general import cat_variant


class AnalysisLinkedDocuments(Collection):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.Collection
                |                     AnalysisLinkedDocuments
                | 
                | The collection of Documents linked by Analysis.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.analysis_linked_documents = com_object

    def item(self, i_index: cat_variant) -> Document:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func Item(CATVariant iIndex) As Document
                | 
                |     Returns a Document by its index or its name from the linked Documents
                |     collection.
                | 
                |     Parameters:
                | 
                |         iIndex
                |             The index or the name of the linked Document to retrieve from the
                |             collection of linked Documents. As a numerics, this index is the rank of the
                |             linked Document in the collection. The index of the first linked Document in
                |             the collection is 1, and the index of the last linked Document is Count. As a
                |             string, it is the name you assigned to the collection by using the
                |             
                | 
                |         AnyObject.Name property. 
                |     Returns:
                |         The retrieved linked Document

        :param cat_variant i_index:
        :rtype: Document
        """
        return Document(self.analysis_linked_documents.Item(i_index))

    def __repr__(self):
        return f'AnalysisLinkedDocuments(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-06-11 12:40:47.360445

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.system_interfaces.any_object import AnyObject


class PrintArea(AnyObject):

    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     PrintArea
                | 
                | Manages print area of drawing sheet.
                | 
                | This interface is obtained from DrawingSheet.PrintArea method.

    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.print_area = com_object

    @property
    def activation_state(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                | o Property ActivationState(boolean iActivated)
                | 
                |     Activates or deactivates the print area.
                | 
                |     Parameters:
                | 
                |         in
                |             boolean iActivated [in] The activation state of the print area
                |             (TRUE means activated, FALSE means deactivated). 
                | 
                |     Returns:
                |         Un HRESULT
                | 
                |         S_OK
                |             The activation state could be valuated. 
                |         E_FAIL
                |             No activation or deactivation possible.

        :rtype: bool
        """

        return self.print_area.ActivationState

    @activation_state.setter
    def activation_state(self, value: bool):
        """
        :param bool value:
        """

        self.print_area.ActivationState = value

    @property
    def area_height(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                | o Property AreaHeigth(double iHeigth)
                | 
                |     Valuates the height of the print area.
                | 
                |     Parameters:
                | 
                |         in
                |             double iHeigth [in] The height of the print area. The value must be
                |             strictly positive. 
                | 
                |     Returns:
                |         Un HRESULT
                | 
                |         S_OK
                |         E_FAIL

        :rtype: float
        """

        return self.print_area.Area_Height

    @area_height.setter
    def area_height(self, value: float):
        """
        :param float value:
        """

        self.print_area.AreaHeigth = value

    @property
    def area_low_x(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                | o Property AreaLowX(double iX)
                | 
                |     Valuates the low x coordinate of the print area.
                | 
                |     Parameters:
                | 
                |         in
                |             double iX [in] The low x coordinate. 
                | 
                |     Returns:
                |         Un HRESULT
                | 
                |         S_OK
                |         E_FAIL

        :rtype: float
        """

        return self.print_area.AreaLowX

    @area_low_x.setter
    def area_low_x(self, value: float):
        """
        :param float value:
        """

        self.print_area.AreaLowX = value

    @property
    def area_low_y(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                | o Property AreaLowY(double iY)
                | 
                |     Valuates the low y coordinate of the print area.
                | 
                |     Parameters:
                | 
                |         in
                |             double iY [in] The low y coordinate. 
                | 
                |     Returns:
                |         Un HRESULT
                | 
                |         S_OK
                |         E_FAIL

        :rtype: float
        """

        return self.print_area.AreaLowY

    @area_low_y.setter
    def area_low_y(self, value: float):
        """
        :param float value:
        """

        self.print_area.AreaLowY = value

    @property
    def area_width(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                | o Property AreaWidth(double iWidth)
                | 
                |     Valuates the width of the print area.
                | 
                |     Parameters:
                | 
                |         in
                |             double iWidth [in] The width of the print area. The value must be
                |             strictly positive. 
                | 
                |     Returns:
                |         Un HRESULT
                | 
                |         S_OK
                |         E_FAIL

        :rtype: float
        """

        return self.print_area.AreaWidth

    @area_width.setter
    def area_width(self, value: float):
        """
        :param float value:
        """

        self.print_area.AreaWidth = float

    def get_area(self, o_x: float, o_y: float, o_width: float, o_height: float, o_activated: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Sub GetArea(double oX,
                | double oY,
                | double oWidth,
                | double oHeigth,
                | boolean oActivated)
                | 
                |     Gets the printing area defined on an object. Also communicates the
                |     activation state of the printing area. 
                | All the values are given in mm.
                | 
                | Parameters:
                | 
                |     out
                |         double oX [out] The low x coordinate of the area. 
                |     out
                |         double oY [out] The low y coordinate of the area. 
                |     out
                |         double oWidth [out] The width of the area. 
                |     out
                |         double oHeigth [out] The height of the area.
                |     out
                |         boolean oActivated [out] The activation state of the print area (TRUE
                |         means activated, FALSE means deactivated). 
                | 
                | Returns:
                |     Un HRESULT
                | 
                |     S_OK
                |         The print area was succesfully retrieved. 
                |     E_FAIL
                |         No print area could be retrived.


        :rtype: None
        """

        vba_function_name = 'get_area'
        vba_code = """
        Public Function get_area(print_area)
            Dim area (5)
            print_area.GetArea area
            get_area = area
        End Function
        """

        system_service = self.application.system_service
        return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_area(self, i_x: float, i_y: float, i_width: float, i_height: float) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Sub SetArea(double iX,
                | double iY,
                | double iWidth,
                | double iHeigth)
                | 
                |     Sets a set of coordinates to define a rectangle print area.
                |     
                | All the values are given in mm.
                | 
                | Parameters:
                | 
                |     in
                |         double iX [in] The low x coordinate of the area. 
                |     in
                |         double iY [in] The low y coordinate of the area. 
                |     in
                |         double iWidth [in] The width of the area. The value must be strictly
                |         positive. 
                |     in
                |         double iHeigth [in] The height of the area. The value must be strictly
                |         positive. 
                | 
                | Returns:
                |     Un HRESULT
                | 
                |     S_OK
                |         The print area was successfully defined. 
                |     E_FAIL
                |         No print area could be defined.

        :param float i_x:
        :param float i_y:
        :param float i_width:
        :param float i_height:
        :rtype: None
        """
        return self.print_area.SetArea(i_x, i_y, i_width, i_height)

    def __repr__(self):
        return f'PrintArea(name="{ self.name }")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-06-11 12:40:47.360445

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

import os
from pathlib import Path

from pycatia.drafting_interfaces.drawing_page_setup import DrawingPageSetup
from pycatia.drafting_interfaces.drawing_views import DrawingViews
from pycatia.drafting_interfaces.print_area import PrintArea
from pycatia.system_interfaces.any_object import AnyObject


class DrawingSheet(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     DrawingSheet
                | 
                | Represents a drawing sheet of the drawing document.
                | 
                | The drawing sheet is included in a drawing document and contains drawing
                | views.
                | Warning: This interface is not available with 2D Layout for 3D
                | Design.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.drawing_sheet = com_object

    @property
    def gen_views_pos_mode(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                | o Property GenViewsPosMode() As CatSheetGenViewsPosMode
                | 
                |     Returns or sets the generative views position stability
                |     mode.
                |     Warning: This method is not available with 2D Layout for 3D
                |     Design.
                | 
                |     Example:
                |         This example sets the stability mode of the MySheet drawing sheet so
                |         that after an update, existing and unmodified geometries don't move
                |         globally.
                | 
                |          MySheet.GenViewsPosMode = catFixedAxis

        :return: enum cat_sheet_gen_views_pos_mode
        :rtype: int
        """

        return self.drawing_sheet.GenViewsPosMode

    @gen_views_pos_mode.setter
    def gen_views_pos_mode(self, value: int):
        """
        :param int value: enum cat_sheet_gen_views_pos_mode
        """

        self.drawing_sheet.GenViewsPosMode = value

    @property
    def orientation(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                | o Property Orientation() As CatPaperOrientation
                | 
                |     Returns or sets the paper orientation.
                | 
                |     Example:
                |         This example sets the paper orientation for the MySheet drawing sheet
                |         to catPaperLandscape.
                | 
                |          MySheet.Orientation = catPaperLandscape

        :return: enum cat_paper_orientation
        :rtype: int
        """

        return self.drawing_sheet.Orientation

    @orientation.setter
    def orientation(self, value: int):
        """
        :param int value: enum cat_paper_orientation
        """

        self.drawing_sheet.Orientation = value

    @property
    def page_setup(self) -> DrawingPageSetup:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                | o Property PageSetup() As DrawingPageSetup (Read Only)
                | 
                |     Returns the page setup.
                | 
                |     Example:
                |         This example returns the page setup for the MySheet drawing
                |         sheet.
                | 
                |          Dim MySheetPageSetup As DrawingPageSetup
                |          Set MySheetPageSetup = MySheet.PageSetup

        :rtype: DrawingPageSetup
        """

        return DrawingPageSetup(self.drawing_sheet.PageSetup)

    @property
    def paper_size(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                | o Property PaperSize() As CatPaperSize
                | 
                |     Returns or sets the paper size.
                | 
                |     Example:
                |         This example sets the page size for the MySheet drawing sheet to
                |         catPaperA4.
                | 
                |          MySheet.PaperSize = catPaperA4

        :return: enum cat_paper_size
        :rtype: int
        """

        return self.drawing_sheet.PaperSize

    @paper_size.setter
    def paper_size(self, value: int):
        """
        :param int value: enum cat_paper_size
        """

        self.drawing_sheet.PaperSize = value

    @property
    def print_area(self) -> PrintArea:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                | o Property PrintArea() As PrintArea (Read Only)
                | 
                |     Returns the print area definition object.
                | 
                |     Example:
                |         This example returns the print area for the MySheet drawing
                |         sheet.
                | 
                |          Dim MyPrintArea As PrintArea
                |          Set MyPrintArea = MySheet.PrintArea

        :rtype: PrintArea
        """

        return PrintArea(self.drawing_sheet.PrintArea)

    @property
    def projection_method(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                | o Property ProjectionMethod() As CatSheetProjectionMethod
                | 
                |     Returns or sets the sheet projection mode .
                | 
                |     Example:
                |         This example sets the projection mode of the MySheet drawing sheet to
                |         catFirstAngle.
                | 
                |          MySheet.ProjectionMethod = catFirstAngle

        :return: enum cat_sheet_projection_method
        :rtype: int
        """

        return self.drawing_sheet.ProjectionMethod

    @projection_method.setter
    def projection_method(self, value: int):
        """
        :param int value: enum cat_sheet_projection_method
        """

        self.drawing_sheet.ProjectionMethod = value

    @property
    def scale(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                | o Property Scale() As double
                | 
                |     Returns or sets the scale of the drawing sheet.
                | 
                |     Example:
                |         This example sets the scale of the MySheet drawing sheet to
                |         0.5.
                | 
                |          MySheet.Scale = 0.5

        :rtype: float
        """

        return self.drawing_sheet.Scale

    @scale.setter
    def scale(self, value: float):
        """
        :param float value:
        """

        self.drawing_sheet.Scale = value

    @property
    def scale2(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                | o Property Scale2() As double
                | 
                |     Returns or sets the scale of the drawing sheet (Workaround for VBA
                |     keyword).
                | 
                |     Example:
                |         This example sets the scale of the MySheet drawing sheet to
                |         0.5.
                | 
                |          MySheet.Scale2 = 0.5

        :rtype: float
        """

        return self.drawing_sheet.Scale2

    @scale2.setter
    def scale2(self, value: float):
        """
        :param float value:
        """

        self.drawing_sheet.Scale2 = value

    @property
    def views(self) -> DrawingViews:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                | o Property Views() As DrawingViews (Read Only)
                | 
                |     Returns the drawing view collection of the drawing sheet.
                |     Warning: This method is not available with 2D Layout for 3D
                |     Design.
                | 
                |     Example:
                |         This example retrieves in ViewCollection the collection of views of the
                |         MySheet drawing sheet.
                | 
                |          Dim ViewCollection As DrawingViews
                |          Set ViewCollection = MySheet.Views

        :rtype: DrawingViews
        """

        return DrawingViews(self.drawing_sheet.Views)

    def activate(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Sub Activate()
                | 
                |     Activates the drawing sheet. Activating a drawing sheet means that this
                |     drawing sheet is the one on which the end user is now working. The window in
                |     the application's window collection which contains this drawing sheet becomes
                |     the active one.
                | 
                |     Example:
                |         This example activates the MySheet drawing sheet.
                | 
                |          MySheet.Activate

        :rtype: None
        """
        return self.drawing_sheet.Activate()

    def force_update(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Sub ForceUpdate()
                | 
                |     Forces the update of all the drawing views of the drawing sheet. This
                |     update redraws all the views, whether their pointed objects have been modified
                |     since the drawing sheet creation or last update or not. These pointed objects
                |     can be CATIA Version 4 models, or CATIA Version 5 parts or
                |     assemblies.
                |     Warning: This method is not available with 2D Layout for 3D
                |     Design.
                | 
                |     Example:
                |         This example forces the update of all the drawing views in the MySheet
                |         drawing sheet.
                | 
                |          MySheet.ForceUpdate

        :rtype: None
        """
        return self.drawing_sheet.ForceUpdate()

    def generate_dimensions(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Sub GenerateDimensions()
                | 
                |     Generates dimensions in all the drawing views of the drawing sheet. These
                |     dimensions are generated from the constraints of the pointed 3D part(s). One
                |     dimension only is generated for a given constraint. Only dimensions for the
                |     following constraints are generated: distance, length, angle, radius, and
                |     diameter.
                |     Warning: This method is not available with 2D Layout for 3D
                |     Design.
                | 
                |     Example:
                |         This example generates the dimensions for all the views in the MySheet
                |         drawing sheet.
                | 
                |          MySheet.GenerateDimensions

        :rtype: None
        """
        return self.drawing_sheet.GenerateDimensions()

    def get_paper_height(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Func GetPaperHeight() As double
                | 
                |     Gets the paper width of the drawing sheet.
                | 
                |     Parameters:
                | 
                |         oPaperHeight
                | 
                |             Example:
                |                 This example get the height of the
                |                 DrawingSheet1.
                | 
                |                  DrawingSheet1.GetPaperHeight oPaperHeight

        :rtype: float
        """
        return self.drawing_sheet.GetPaperHeight()

    def get_paper_width(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Func GetPaperWidth() As double
                | 
                |     Gets the paper width of the drawing sheet.
                | 
                |     Parameters:
                | 
                |         oPaperWidth
                | 
                |             Example:
                |                 This example get the width of the
                |                 DrawingSheet1.
                | 
                |                  DrawingSheet1.GetPaperWidth oPaperWidth

        :rtype: float
        """
        return self.drawing_sheet.GetPaperWidth()

    def is_detail(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Func IsDetail() As boolean
                | 
                |     Checks whether the sheet is a detail sheet.
                |     Warning: This method is not available with 2D Layout for 3D
                |     Design.
                |     TRUE if the sheet is a detail sheet.
                | 
                |     Example:
                |         This example checks whether MySheet is a detail sheet.
                | 
                |          IsDetail = MySheet.IsDetail

        :rtype: bool
        """
        return self.drawing_sheet.IsDetail()

    def isolate(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Sub Isolate()
                | 
                |     Isolates the drawing sheet.
                |     Warning: This method is not available with 2D Layout for 3D
                |     Design.
                | 
                |     Example:
                |         This example isolates the MySheet drawing sheet.
                | 
                |          MySheet.Isolate

        :rtype: None
        """
        return self.drawing_sheet.Isolate()

    def print_out(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Sub PrintOut()
                | 
                |     Prints the drawing sheet according to its page setup on the default
                |     printer.
                |     Warning: This method is not available with 2D Layout for 3D
                |     Design.
                | 
                |     Example:
                |         This example prints the DrawingSheet1 on the default
                |         printer.
                | 
                |          DrawingSheet1.PrintOut

        :rtype: None
        """
        return self.drawing_sheet.PrintOut()

    def print_to_file(self, file_name: Path, overwrite=False) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Sub PrintToFile(CATBSTR fileName)
                | 
                |     Prints the drawing sheet according its page setup in a file instead of
                |     being sent to a printer.
                | 
                |     Parameters:
                | 
                |         fileName
                |             The full pathname of the file receiving the data.
                |             Warning: This method is not available with 2D Layout for 3D Design.
                |             
                | 
                |     Example:
                |         This example prints the DrawingSheet1 in a file.
                | 
                |          DrawingSheet1.PrintToFile "e://temp//sheet1.prn"

        :param Path file_name: file_name including full path.
        :param bool overwrite: Files will not be overwritten unless is True.
        :rtype: None
        """

        if not isinstance(file_name, Path):
            file_name = Path(file_name)

        if str(file_name.parent) == '.':
            self.logger.warning('Full path to print file expected. Assuming current working directory.')
            file_name = Path(os.getcwd(), file_name)

        if not file_name.parent.is_dir():
            raise NotADirectoryError(f'Directory {file_name.parent} is not a directory.')

        if overwrite is False and file_name.is_file():
            raise FileExistsError(f'File: {file_name} already exists. '
                                  f'Set overwrite=True if you want to overwrite.')

        # pycatia prefers full path names :-)
        if not file_name.is_absolute():
            self.logger.warning('To prevent unexpected behaviour, be explicit and use absolute filenames.')

        self.drawing_sheet.PrintToFile(file_name)

    def set_as_detail(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Sub SetAsDetail()
                | 
                |     Sets the sheet as a detail sheet. You can now create views into this sheet
                |     that will be taken as details. A detail is made to be reuse as dittos in
                |     views.
                |     Warning: This method is not available with 2D Layout for 3D
                |     Design.
                | 
                |     Example:
                |         This example changes the MySheet into a detail sheet.
                | 
                |          MySheet.SetAsDetail

        :rtype: None
        """
        return self.drawing_sheet.SetAsDetail()

    def set_paper_height(self, o_paper_height: float) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Sub SetPaperHeight(double oPaperHeight)
                | 
                |     Sets the paper width of the drawing sheet, available on user
                |     format.
                | 
                |     Parameters:
                | 
                |         iPaperHeight
                | 
                |             Example:
                |                 This example set the height of the
                |                 DrawingSheet1.
                | 
                |                  DrawingSheet1.PaperSize = catPaperUser
                |                  DrawingSheet1.SetPaperHeight iPaperHeight

        :param float o_paper_height:
        :rtype: None
        """
        return self.drawing_sheet.SetPaperHeight(o_paper_height)

    def set_paper_width(self, o_paper_width: float) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Sub SetPaperWidth(double oPaperWidth)
                | 
                |     Sets the paper width of the drawing sheet, available on user
                |     format.
                | 
                |     Parameters:
                | 
                |         iPaperWidth
                | 
                |             Example:
                |                 This example set the width of the
                |                 DrawingSheet1.
                | 
                |                  DrawingSheet1.PaperSize = catPaperUser
                |                  DrawingSheet1.SetPaperWidth iPaperWidth

        :param float o_paper_width:
        :rtype: None
        """
        return self.drawing_sheet.SetPaperWidth(o_paper_width)

    def update(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Sub Update()
                | 
                |     Updates the drawing views of the drawing sheet. This update redraws all the
                |     views whose pointed objects have been modified since the drawing sheet creation
                |     or last update, but do not redraw the views whose pointed have not been
                |     modifed. These pointed objects can be CATIA Version 4 models, or CATIA Version
                |     5 parts or assemblies.
                |     Warning: This method is not available with 2D Layout for 3D
                |     Design.
                | 
                |     Example:
                |         This example updates the drawing views in the MySheet drawing
                |         sheet.
                | 
                |          MySheet.Update

        :rtype: None
        """
        return self.drawing_sheet.Update()

    def reorder_views(self, i_ordered_views: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Sub reorder_Views(CATSafeArrayVariant iOrderedViews)
                | 
                |     Changes the positions of the views in this sheet according to the given
                |     ordered list. iOrderedViews is the result of a permutation applied to the list
                |     of all the views of this sheet with the following constraint: the two first
                |     elements of the list must be respectively the sheet's mainview and background
                |     view.
                | 
                |     Example:
                |         This example modifies the views order of a sheet made of a mainview, a
                |         backgroundview and two user-created views. (user-created views are
                |         inverted).
                | 
                |          Set drwviewsorder = CATIA.ActiveDocument.Sheets.ActiveSheet
                |          Set drwviews = drwviewsorder.Views
                |          Set mainview = drwviews.item(1)
                |          Set backview = drwviews.item(2)
                |          Set view1 = drwviews.item(3)
                |          Set view2 = drwviews.item(4)
                |          newvieworder = Array(mainview, backview, view2, view1)
                |          drwviewsorder.reorder_Views(newvieworder)

        :param tuple i_ordered_views:
        :rtype: None
        """
        return self.drawing_sheet.reorder_Views(i_ordered_views)
        # # # # Autogenerated comment:
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'reorder_views'
        # # vba_code = """
        # # Public Function reorder_views(drawing_sheet)
        # #     Dim iOrderedViews (2)
        # #     drawing_sheet.reorder_Views iOrderedViews
        # #     reorder_views = iOrderedViews
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'DrawingSheet(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from typing import TYPE_CHECKING

from pycatia.analysis_interfaces.analysis_entities import AnalysisEntities
from pycatia.analysis_interfaces.analysis_images import AnalysisImages
from pycatia.analysis_interfaces.analysis_output_entities import AnalysisOutputEntities
from pycatia.analysis_interfaces.basic_components import BasicComponents
from pycatia.system_interfaces.any_object import AnyObject

if TYPE_CHECKING:
    from pycatia.analysis_interfaces.analysis_sets import AnalysisSets


class AnalysisSet(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     AnalysisSet
                | 
                | Represent the analysis set object.
                | In the Analysis Model, an Analysis Set is the data dedicated to manage the
                | Analysis Entities for specific preprocessing data.
                | For example, LoadSet will manage loading conditions...
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.analysis_set = com_object

    @property
    def analysis_entities(self) -> AnalysisEntities:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property AnalysisEntities() As AnalysisEntities (Read Only)
                | 
                |     Returns the analysis entities collection associated to a set. The
                |     corresponding entities are default preprocessing objects.
                | 
                |     Example :
                |         This example retrieves analysis entities collection .
                | 
                |          Dim MySet As AnalysisSet
                |          Dim analysisEntities As AnalysisEntities
                |          Set analysisEntities = MySet.AnalysisEntities

        :rtype: AnalysisEntities
        """

        return AnalysisEntities(self.analysis_set.AnalysisEntities)

    @property
    def analysis_images(self) -> AnalysisImages:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property AnalysisImages() As AnalysisImages (Read Only)
                | 
                |     Returns the analysis images collection associated with an analysis
                |     set.
                | 
                |     Example:
                |         This example retrieves analysisimages collection .
                | 
                |          Dim MySet As AnalysisSet
                |          Dim analysisimages As AnalysisImages
                |          Set analysisimages = MySet.AnalysisImages

        :rtype: AnalysisImages
        """

        return AnalysisImages(self.analysis_set.AnalysisImages)

    @property
    def analysis_output_entities(self) -> AnalysisOutputEntities:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property AnalysisOutputEntities() As AnalysisOutputEntities (Read
                | Only)
                | 
                |     Returns the analysis entities collection associated to a set. The
                |     corresponding entities are not preprocessing features but can be used, for
                |     example to manage error features.
                | 
                |     Example:
                |         This example retrieves analysisEntities collection .
                | 
                |          Dim MySet As AnalysisSet
                |          Dim analysisEntities As AnalysisOutputEntities
                |          Set analysisEntities = MySet.AnalysisOutputEntities

        :rtype: AnalysisOutputEntities
        """

        return AnalysisOutputEntities(self.analysis_set.AnalysisOutputEntities)

    @property
    def analysis_sets(self) -> 'AnalysisSets':
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property AnalysisSets() As AnalysisSets (Read Only)
                | 
                |     Returns the analysis sets collection associated with an analysis set. This
                |     method will return a collection only if the set is made of other
                |     sets.
                | 
                |     Example:
                |         This example retrieves analysisSets collection .
                | 
                |          Dim MySet As AnalysisSet
                |          Dim analysisSets As AnalysisSets
                |          Set analysisSets = MySet.AnalysisSets

        :rtype: AnalysisSets
        """

        from pycatia.analysis_interfaces.analysis_sets import AnalysisSets
        return AnalysisSets(self.analysis_set.AnalysisSets)

    @property
    def basic_components(self) -> BasicComponents:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property BasicComponents() As BasicComponents (Read Only)
                | 
                |     Returns the basic components collection associated with an analysis
                |     set.
                | 
                |     Example:
                |         This example retrieves basiccomponents collection .
                | 
                |          Dim MySet As AnalysisSet
                |          Dim basiccomponents As BasicComponents 
                |          Set basiccomponents = MySet.BasicComponents

        :rtype: BasicComponents
        """

        return BasicComponents(self.analysis_set.BasicComponents)

    @property
    def type(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Type() As CATBSTR (Read Only)
                | 
                |     Returns the type of the analysis Set.
                | 
                |     Example:
                |         The following example returns TypeofSet of MySet.
                | 
                |          Dim MySet As AnalysisSet
                |          Dim TypeofSet As CATBSTR
                |          Set TypeofSet = MySet.Type

        :rtype: str
        """

        return self.analysis_set.Type

    def update(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub Update()
                | 
                |     Launch the update (computation if needed) of an AnalysisSet.

        :rtype: None
        """
        return self.analysis_set.Update()

    def __repr__(self):
        return f'AnalysisSet(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.cat_sch_platform_interfaces.sch_internal_flow import SchInternalFlow
from pycatia.cat_sch_platform_interfaces.sch_list_of_objects import SchListOfObjects
from pycatia.system_interfaces.any_object import AnyObject


class SchCompFlow(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     SchCompFlow
                | 
                | Manage the internal flow of a schematic component.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.sch_comp_flow = com_object

    def add_internal_flow(self, i_l_flow_cntrs: SchListOfObjects) -> SchInternalFlow:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func AddInternalFlow(SchListOfObjects iLFlowCntrs) As
                | SchInternalFlow
                | 
                |     Add an internal flow to a component.
                | 
                |     Parameters:
                | 
                |         iLFlowCntrs
                |             List of connectors (2) to be connected by the flow. (members should
                |             be CATISchAppConnector interface pointer) 
                |         oInternalFlowAdded
                |             Internal flow object added/created (CATISchInternalFlow interface
                |             pointer). 
                | 
                |     Example:
                |
                |          Dim objThisIntf As SchCompFlow
                |          Dim objArg1 As SchListOfObjects
                |          Dim objArg2 As SchInternalFlow
                |           ...
                |          Set objArg2 = objThisIntf.AddInternalFlow(objArg1)

        :param SchListOfObjects i_l_flow_cntrs:
        :rtype: SchInternalFlow
        """
        return SchInternalFlow(self.sch_comp_flow.AddInternalFlow(i_l_flow_cntrs.com_object))

    def add_internal_flow_specify_grr(
            self,
            i_l_flow_cntrs: SchListOfObjects,
            i_l_owner_grr: SchListOfObjects
    ) -> SchInternalFlow:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func AddInternalFlowSpecifyGRR(SchListOfObjects
                | iLFlowCntrs,
                | SchListOfObjects iLOwnerGRR) As SchInternalFlow
                | 
                |     Add an internal flow to a component. Specifying which graphical images the
                |     connector graphics are on.
                | 
                |     Parameters:
                | 
                |         iLFlowCntrs
                |             List of connectors (2) to be connected by the flow. (members should
                |             be CATISchAppConnector interface pointer) 
                |         iLOwnerImages
                |             List of CATISchGRRComp interface pointers 
                |         oInternalFlowAdded
                |             Internal flow object added/created (CATISchInternalFlow interface
                |             pointer). 
                | 
                |     Example:
                |
                |          Dim objThisIntf As SchCompFlow
                |          Dim objArg1 As SchListOfObjects
                |          Dim objArg2 As SchListOfObjects
                |          Dim objArg3 As SchInternalFlow
                |           ...
                |          Set objArg3 = objThisIntf.AddInternalFlowSpecifyGRR(objArg1,objArg2)

        :param SchListOfObjects i_l_flow_cntrs:
        :param SchListOfObjects i_l_owner_grr:
        :rtype: SchInternalFlow
        """
        return SchInternalFlow(
            self.sch_comp_flow.AddInternalFlowSpecifyGRR(
                i_l_flow_cntrs.com_object,
                i_l_owner_grr.com_object
            )
        )

    def list_internal_flows(self) -> SchListOfObjects:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func ListInternalFlows() As SchListOfObjects
                | 
                |     List all internal flow objects of a component.
                | 
                |     Parameters:
                | 
                |         oLInternalFlow
                |             A list of internal flow objects (members are CATISchInternalFlow
                |             interface pointers). 
                | 
                |     Example:
                |
                |          Dim objThisIntf As SchCompFlow
                |          Dim objArg1 As SchListOfObjects
                |           ...
                |          Set objArg1 = objThisIntf.ListInternalFlows

        :rtype: SchListOfObjects
        """
        return SchListOfObjects(self.sch_comp_flow.ListInternalFlows())

    def remove_internal_flow(self, i_internal_flow_to_remove: SchInternalFlow) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub RemoveInternalFlow(SchInternalFlow
                | iInternalFlowToRemove)
                | 
                |     Remove an internal flow from a component.
                | 
                |     Parameters:
                | 
                |         iInternalFlowToRemove
                |             Internal flow object to be removed. 
                | 
                |     Example:
                |
                |          Dim objThisIntf As SchCompFlow
                |          Dim objArg1 As SchInternalFlow
                |           ...
                |          objThisIntf.RemoveInternalFlowobjArg1

        :param SchInternalFlow i_internal_flow_to_remove:
        :rtype: None
        """
        return self.sch_comp_flow.RemoveInternalFlow(i_internal_flow_to_remove.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'remove_internal_flow'
        # # vba_code = """
        # # Public Function remove_internal_flow(sch_comp_flow)
        # #     Dim iInternalFlowToRemove (2)
        # #     sch_comp_flow.RemoveInternalFlow iInternalFlowToRemove
        # #     remove_internal_flow = iInternalFlowToRemove
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'SchCompFlow(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.dnb_resource_program_interfaces.task import Task
from pycatia.system_interfaces.any_object import AnyObject


class ActiveTask(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     ActiveTask
                | 
                | Represents the Active task of the resource in conjunction with a particular
                | activity.
                | 
                | Role: Active Task is the object used to access and manage the active task set
                | for all the resources assigned for the activity.
                | The following code snippet can be used to obtain the Active Task from the
                | activity.
                | 
                |    Dim objChildActivity As Activity
                |    Dim objActiveActivity As ActiveTask
                |    
                |    Set objActiveActivity = objChildActivity.GetTechnologicalObject("ActiveTask")
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.active_task = com_object

    def get_active_task(self, i_resource: AnyObject, o_task: Task) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetActiveTask(AnyObject iResource,
                | Task oTask)
                | 
                |     Retrieves the Active Task for an activity for a particular
                |     Resource.
                | 
                |     Parameters:
                | 
                |         iResource
                |             The resources. 
                |         oTask
                |             The Active Task. 
                | 
                |     Returns:
                |         An HRESULT.
                |         Legal values:
                | 
                |         S_OK
                |             The status could be successfully queried from the
                |             activity
                |         E_FAIL
                |             The query failed.
                | 
                |         Example:
                |             The following example get the active task of the particular
                |             resource in the activity.
                | 
                |                Dim oActiveAct As ActiveTask
                |                Dim iResPrgMngr As ResourceProgramManager
                |                Dim oTask As Task
                |                ..
                |                oActiveAct.GetActiveTask iResPrgMngr, oTask

        :param AnyObject i_resource:
        :param Task o_task:
        :rtype: None
        """
        return self.active_task.GetActiveTask(i_resource.com_object, o_task.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_active_task'
        # # vba_code = """
        # # Public Function get_active_task(active_task)
        # #     Dim iResource (2)
        # #     active_task.GetActiveTask iResource
        # #     get_active_task = iResource
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_active_task(self, i_resource: AnyObject, i_task: Task) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetActiveTask(AnyObject iResource,
                | Task iTask)
                | 
                |     Defines the Active Task for an activity for a particular
                |     Resource.
                | 
                |     Parameters:
                | 
                |         iResource
                |             The resources that owns the Task. 
                |         iTask
                |             The Tasks to be made active. 
                | 
                |     Returns:
                |         An HRESULT.
                |         Legal values:
                | 
                |         S_OK
                |             The Active Task was corrrectly set
                |         E_FAIL
                |             The Active Task was not corrrectly set
                | 
                |         Example:
                |             The following example sets Active Task for an activity for a
                |             particular Resource.
                | 
                |                Dim iActiveAct As ActiveTask
                |                Dim iResPrgMngr As ResourceProgramManager
                |                Dim iTask As Task
                |                ..
                |                oActiveAct.SetActiveTask iResPrgMngr, iTask

        :param AnyObject i_resource:
        :param Task i_task:
        :rtype: None
        """
        return self.active_task.SetActiveTask(i_resource.com_object, i_task.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_active_task'
        # # vba_code = """
        # # Public Function set_active_task(active_task)
        # #     Dim iResource (2)
        # #     active_task.SetActiveTask iResource
        # #     set_active_task = iResource
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'ActiveTask(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.dnb_robot_interfaces.rob_generic_controller import RobGenericController
from pycatia.system_interfaces.any_object import AnyObject


class GenericAccuracyProfile(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     GenericAccuracyProfile
                | 
                | Interface to manage Generic Accuracy Profile of Robot
                | controller.
                | 
                | Role: This interface provides methods to get/set data related to Accuracy
                | Profile.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.generic_accuracy_profile = com_object

    def get_accuracy_type(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetAccuracyType(AccuracyType accuracy)
                | 
                |     Get the accuracy type for the profile.
                | 
                |     Parameters:
                | 
                |         accurancy
                |             accurancy type to get, could be ACCURACY_TYPE_DISTANCE /
                |             ACCURACY_TYPE_SPEED 
                | 
                |     Returns:
                |         An HRESULT.
                |         Legal values:
                | 
                |             S_OK if the operation succeeds
                |             E_FAIL otherwise

        :return: enum accuracy_type
        :rtype: int
        """
        return self.generic_accuracy_profile.GetAccuracyType()

    def get_accuracy_value(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetAccuracyValue(double value)
                | 
                |     Retrieves accuracy value of the profile.
                | 
                |     Parameters:
                | 
                |         value
                |             This parameter contains accuracy value. 
                | 
                |     Returns:
                |         An HRESULT.
                |         Legal values:
                | 
                |             S_OK if the operation succeeds
                |             E_FAIL otherwise

        :rtype: float
        """
        return self.generic_accuracy_profile.GetAccuracyValue()

    def get_controller(self) -> RobGenericController:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetController(RobGenericController oController)
                | 
                |     Retrieves controller owning the profile.
                | 
                |     Parameters:
                | 
                |         oController
                |             This parameter contains pointer to controller. 
                | 
                |     Returns:
                |         An HRESULT.
                |         Legal values:
                | 
                |             S_OK if the operation succeeds
                |             E_FAIL otherwise

        :rtype: RobGenericController
        """
        return self.generic_accuracy_profile.GetController()
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_controller'
        # # vba_code = """
        # # Public Function get_controller(generic_accuracy_profile)
        # #     Dim oController (2)
        # #     generic_accuracy_profile.GetController oController
        # #     get_controller = oController
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def get_fly_by_mode(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetFlyByMode(boolean oMode)
                | 
                |     Gets On/Off status of Flyby mode.
                | 
                |     Parameters:
                | 
                |         oMode
                |             mode indicating On/Off status. 
                | 
                |     Returns:
                |         an HRESULT value.
                |         Legal values:
                | 
                |             S_OK if the operation succeeds
                |             E_FAIL otherwise

        :rtype: bool
        """
        return self.generic_accuracy_profile.GetFlyByMode()
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_fly_by_mode'
        # # vba_code = """
        # # Public Function get_fly_by_mode(generic_accuracy_profile)
        # #     Dim oMode (2)
        # #     generic_accuracy_profile.GetFlyByMode oMode
        # #     get_fly_by_mode = oMode
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def get_name(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetName(CATBSTR oName)
                | 
                |     Gets name of the Accuracy Profile.
                | 
                |     Parameters:
                | 
                |         oName
                |             Name of the required Accuracy Profile. 
                | 
                |     Returns:
                |         an HRESULT value.
                |         Legal values:
                | 
                |             S_OK if the operation succeeds
                |             E_FAIL otherwise

        :rtype: str
        """
        return self.generic_accuracy_profile.GetName()

    def set_accuracy_type(self, accuracy: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetAccuracyType(AccuracyType accuracy)
                | 
                |     Set the accuracy type for the profile.
                | 
                |     Parameters:
                | 
                |         accurancy
                |             accurancy type to set, could be ACCURACY_TYPE_DISTANCE /
                |             ACCURACY_TYPE_SPEED 
                | 
                |     Returns:
                |         An HRESULT.
                |         Legal values:
                | 
                |             S_OK if the operation succeeds
                |             E_FAIL otherwise

        :param int accuracy: enum accuracy_type
        :rtype: None
        """
        return self.generic_accuracy_profile.SetAccuracyType(accuracy)

    def set_accuracy_value(self, value: float) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetAccuracyValue(double value)
                | 
                |     Set accuracy value of the profile.
                | 
                |     Parameters:
                | 
                |         value
                |             This parameter is percentage or absolute value, depending on
                |             accurancy type. 
                | 
                |     Returns:
                |         An HRESULT.
                |         Legal values:
                | 
                |             S_OK if the operation succeeds
                |             E_FAIL otherwise

        :param float value:
        :rtype: None
        """
        return self.generic_accuracy_profile.SetAccuracyValue(value)

    def set_fly_by_mode(self, i_mode: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetFlyByMode(boolean iMode)
                | 
                |     Switch On/Off Flyby mode.
                | 
                |     Parameters:
                | 
                |         iMode
                |             mode indicating On/Off status. 
                | 
                |     Returns:
                |         an HRESULT value.
                |         Legal values:
                | 
                |             S_OK if the operation succeeds
                |             E_FAIL otherwise

        :param bool i_mode:
        :rtype: None
        """
        return self.generic_accuracy_profile.SetFlyByMode(i_mode)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_fly_by_mode'
        # # vba_code = """
        # # Public Function set_fly_by_mode(generic_accuracy_profile)
        # #     Dim iMode (2)
        # #     generic_accuracy_profile.SetFlyByMode iMode
        # #     set_fly_by_mode = iMode
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_name(self, i_name: str) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetName(CATBSTR iName)
                | 
                |     Set name of the Accuracy Profile.
                | 
                |     Parameters:
                | 
                |         iName
                |             Name of the Accuracy Profile to be set. 
                | 
                |     Returns:
                |         an HRESULT value.
                |         Legal values:
                | 
                |             S_OK if the operation succeeds
                |             E_FAIL otherwise

        :param str i_name:
        :rtype: None
        """
        return self.generic_accuracy_profile.SetName(i_name)

    def __repr__(self):
        return f'GenericAccuracyProfile(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.system_interfaces.any_object import AnyObject
from pycatia.types.general import cat_variant


class FunctAssociation(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     FunctAssociation
                | 
                | The interface to access a Functional Association.
                | 
                | It is managed on a Functional Element, thru the MultiRep Facet Manager
                | (MRM).
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.funct_association = com_object

    @property
    def linked_count(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property LinkedCount() As long (Read Only)
                | 
                |     Get count of linked objects.

        :rtype: int
        """

        return self.funct_association.LinkedCount

    def detach_from(self, i_linked: AnyObject) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub DetachFrom(AnyObject iLinked)
                | 
                |     Delete a link to a linked object.

        :param AnyObject i_linked:
        :rtype: None
        """
        return self.funct_association.DetachFrom(i_linked.com_object)

    def link_to(self, i_linked: AnyObject, i_kind: str) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub LinkTo(AnyObject iLinked,
                | CATBSTR iKind)
                | 
                |     Create a link to another object.

        :param AnyObject i_linked:
        :param str i_kind:
        :rtype: None
        """
        return self.funct_association.LinkTo(i_linked.com_object, i_kind)

    def retrieve_kind_of_linked(self, i_index: cat_variant) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func RetrieveKindOfLinked(CATVariant iIndex) As CATBSTR
                | 
                |     Retrieve the kind of linked object.

        :param cat_variant i_index:
        :rtype: str
        """
        return self.funct_association.RetrieveKindOfLinked(i_index)

    def retrieve_linked(self, i_index: cat_variant) -> AnyObject:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func RetrieveLinked(CATVariant iIndex) As AnyObject
                | 
                |     Retrieve a linked object.

        :param cat_variant i_index:
        :rtype: AnyObject
        """
        return AnyObject(self.funct_association.RetrieveLinked(i_index))

    def __repr__(self):
        return f'FunctAssociation(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.system_interfaces.any_object import AnyObject


class DnbAttachmentFactory(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     DNBAttachmentFactory
                | 
                | Interface representing xxx.
                | 
                | Role: Components that implement DNBIABasicDevice are ...
                | 
                | Do not use the DNBIAMRLAttachmentFactory interface for such and such
                | ClassReference, Class#MethodReference, #InternalMethod...
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.dnb_attachment_factory = com_object

    def attach(self, i_parent: AnyObject, i_child: AnyObject, o_attachment: AnyObject) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub Attach(CATBaseDispatch iParent,
                | CATBaseDispatch iChild,
                | CATBaseDispatch oAttachment)
                | 
                |     Attach a Product/MA with another Product/MA
                | 
                |     Parameters:
                | 
                |         iParent
                |             This input parameter contains the Parent product/MA of the
                |             attachment to be created 
                |         iChild
                |             This input parameter contains the Child product/MA of the
                |             attachment to be created 
                |         oAttachment
                |             This output parameter contains the attachment that is created.
                |
                |     Returns:
                |         An HRESULT

        :param AnyObject i_parent:
        :param AnyObject i_child:
        :param AnyObject o_attachment:
        :rtype: None
        """
        return self.dnb_attachment_factory.Attach(i_parent.com_object, i_child.com_object, o_attachment.com_object)

    def remove(self, i_attachment: AnyObject) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub Remove(CATBaseDispatch iAttachment)
                | 
                |     Remove an attachment.
                | 
                |     Parameters:
                | 
                |         iAttachment
                |             This input parameter contains the Attachment to be deleted.
                |
                |     Returns:
                |         An HRESULT

        :param AnyObject i_attachment:
        :rtype: None
        """
        return self.dnb_attachment_factory.Remove(i_attachment.com_object)

    def __repr__(self):
        return f'DnbAttachmentFactory(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.system_interfaces.any_object import AnyObject


class Joint(AnyObject):

    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     Joint
                | 
                | Interface to manage the Joint object.
                | Depending on their type, joints have parameters or not, representing length or
                | angle:
                | Joint type 	Parameter1 	Parameter2
                | Revolute 	Angle 	
                | Prismatic 	Length 	
                | Cylindrical 	Length 	Angle
                | Screw 	Length 	Angle
                | Gear 	Angle 	Angle
                | Rack 	Length 	Angle
                | Cable 	Length 	Length
                | PointOnCurve 	Length 	
                | RollCurve 	Length 	
                | 
                | Each parameter can have a lower and/or an upper limit.
                | 
                | Methods are provided to set, unset and return the limits for each
                | parameter.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.joint = com_object

    def unset_lower_limit1(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub UnsetLowerLimit1()
                | 
                |     Unsets the lower limit of the joint, for the first
                |     parameter.
                | 
                |     Parameters:
                | 
                |         iLimitValue
                |             The value for the limit When reading, an error is returned if the
                |             joint type has no such parameter, or if the limit is
                |             unset.

        :rtype: None
        """
        return self.joint.UnsetLowerLimit1()

    def unset_lower_limit2(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub UnsetLowerLimit2()
                | 
                |     Unsets the lower limit of the joint, for the second
                |     parameter.
                | 
                |     Parameters:
                | 
                |         iLimitValue
                |             The value for the limit

        :rtype: None
        """
        return self.joint.UnsetLowerLimit2()

    def unset_upper_limit1(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub UnsetUpperLimit1()
                | 
                |     Unsets the upper limit of the joint, for the first
                |     parameter.
                | 
                |     Parameters:
                | 
                |         iLimitValue
                |             The value for the limit

        :rtype: None
        """
        return self.joint.UnsetUpperLimit1()

    def unset_upper_limit2(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub UnsetUpperLimit2()
                | 
                |     Unsets the upper limit of the joint, for the second
                |     parameter.
                | 
                |     Parameters:
                | 
                |         iLimitValue
                |             The value for the limit

        :rtype: None
        """
        return self.joint.UnsetUpperLimit2()

    def __repr__(self):
        return f'Joint(name="{ self.name }")'
